<?php namespace Lunovus\ExternalStore;

use Lunovus\ExternalStore\Shortcodes\Cart as CartShortcode;

class Client
{
    public static function init()
    {
        self::setRewriteRules();
        self::enqueueStyles();
        self::addShortcodes();
        self::insertCartShortCode();
    }

    /**
     * Enqueue common styles
     */
    public static function enqueueStyles()
    {
        $version = (LUNOVUS_EXTERNAL_STORE__ENVIRONMENT == 'production')
            ? LUNOVUS_EXTERNAL_STORE_VERSION
            : time();

        wp_enqueue_style(
            LUNOVUS_EXTERNAL_STORE_NAME . '-css',
            LUNOVUS_EXTERNAL_STORE__PLUGIN_BUILD_URL . 'css/style.css',
            [],
            $version
        );
    }

    /**
     * Add shortcodes
     */
    public static function addShortcodes()
    {
        CartShortcode::init();
    }

    /**
     * Set rewrite rules for React pages
     */
    public static function setRewriteRules()
    {
        // Add custom query vars
        add_filter('query_vars', function($vars) {
            $vars[] = 'lunovus_category_slug';
            $vars[] = 'lunovus_product_slug';
            $vars[] = 'account_page';
            return $vars;
        });

        // Add rewrite rules
        add_action('init', function() {
            add_rewrite_rule(
                '^(shop)/([^/]*)/([^/]*)/?', 
                'index.php?pagename=$matches[1]&lunovus_category_slug=$matches[2]&lunovus_product_slug=$matches[3]',
                'top'
            );
            add_rewrite_rule(
                '^(shop)/([^/]*)/?',
                'index.php?pagename=$matches[1]&lunovus_category_slug=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                '^(account)/([^/]*)/?', 
                'index.php?pagename=$matches[1]&account_page=$matches[2]',
                'top'
            );

            flush_rewrite_rules(true);
        });
    }

    /**
     * Insert [lunovus-cart] shortcode to each public page
     */
    public static function insertCartShortCode() 
    {
        if (is_admin())
        {
            return false;
        }

        $devMenu = '<div class="t-container t-px-10" style="max-width: 1280px!important">
            <a href="/account">Account</a>
            * <a href="/shop/all">Shop</a>
            * <a href="/account/register">Register</a>
            * <a href="/account/logout">Logout</a>
        </div>';
        
        add_filter('the_content', function ($content) use ($devMenu)
        {
            if (LUNOVUS_EXTERNAL_STORE__ENVIRONMENT === 'local')
            {
                $content = $devMenu . $content;
            }

            return $content .= do_shortcode('[lunovus-cart]');
        });
    }
}
