<?php namespace Lunovus\ExternalStore\Shortcodes;

use Lunovus\ExternalStore\Helpers;
use Lunovus\ExternalStore\API;

class Shop
{
    const NAME = 'lunovus-shop';

    public static function init()
    {
        add_shortcode(self::NAME, [get_called_class(), 'callback']);
    }

    /**
     * Shortcode callback
     */
    public static function callback()
    {
        global $wp_query;

        Helpers::enqueueReactScript('shop');

        $practiceId = LUNOVUS_EXTERNAL__PRACTICE_ID;
        $categorySlug = $wp_query->query_vars['lunovus_category_slug'] ?: 'all';
        $productSlug = $wp_query->query_vars['lunovus_product_slug'] ?: null;
        $productSku = end(explode('-', $productSlug));
        $categories = API::getCategories($practiceId);
        $categoriesSlugs = array_combine(
            array_column($categories, 'id'),
            array_column($categories, 'slug')
        );

        $currentCategory = Helpers::arraySearch($categories, 'slug', $categorySlug);

        $layoutName = '';
        $layoutVars = [
            'practiceId' => $practiceId,
            'categorySlug' => $categorySlug,
            'productSlug' => $productSlug,
            'categories' => $categories,
            'categoriesSlugs' => $categoriesSlugs,
            'currentCategory' => $currentCategory,
            'product' => null,
            'products' => []
        ];

        if ($productSlug)
        {
            // Request product
            Helpers::setPageTitle([$currentCategory->title, $product->title]);
            Helpers::addMetaTag('description', $currentCategory->title . ' - ' . $product->title . '. ' . $product->meta_description);
            
            $product = API::getProduct($practiceId, $productSku);

            $layoutName = 'product';
            $layoutVars['product'] = $product;
        }
        else
        {
            // Request category listing
            Helpers::setPageTitle(['Shop', $currentCategory->title]);
            Helpers::addMetaTag('description', $currentCategory->title);

            $products = API::getProducts($practiceId, [
                'category_id' => $currentCategory ? $currentCategory->id : '',
                'limit' => $_GET['limit'] ?: 100,
                'offset' => $_GET['offset'] ?: 0,
                'order' => $_GET['order'] ?: []
            ]);
            $products = $products ? $products->data : [];

            $layoutName = 'category';
            $layoutVars['products'] = $products;
        }

        // Layout for no JS
        $noJsLayout = Helpers::getLayoutHTML($layoutName, $layoutVars);

        $filters = [
            'practice_id' => $practiceId,
            'category_id' => $currentCategory->id,
            'offset' => $products->offset,
            'limit' => $products->limit,
            'total' => $products->total,
            'filtered' => $products->filtered,
            'hasMore' => $products->hasMore,
            'order' => $_GET['order'] ?: []
        ];
        
        // React Shop component root
        $html .= '<div id="lunovus-external-store-shop" class="t-container t-mx-auto t-mb-14 t-p-0 md:t-p-10" style="max-width: 1280px!important"
            data-practice-id="' . $practiceId . '"
            data-categories=\'' . json_encode($categories ?: []) . '\'
            data-categories_slugs=\'' . json_encode($categoriesSlugs ?: []) . '\'
            data-products=\'' . json_encode($products->data ?: []) . '\'
            data-filters=\'' . json_encode($filters ?: []) . '\'
            data-current_category=\'' . json_encode($currentCategory ?: []) . '\'
            data-current_product=\'' . json_encode($product ?: []) . '\'
        >';
        $html .= $noJsLayout;
        $html .= '</div>';

        return $html;
    }
}
